@@ -39,14 +39,14 @@ __copyright__ = """
 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-__version__ = "0.0.6"
+__version__ = "0.0.8"
 modname = "default_values"
 pypi_name = "default_values"
 import_name = "sphinxcontrib.default_values"
 __license__ = "MIT License"
-short_desc = "Sphinx extension to show default values in documentation."
-__author__ = author = "Dominic Davis-Foster"
-author_email = "dominic@davis-foster.co.uk"
+short_desc = 'Sphinx extension to show default values in documentation.'
+__author__ = author = 'Dominic Davis-Foster'
+author_email = 'dominic@davis-foster.co.uk'
 github_username = "domdfcoding"
 web = github_url = "https://github.com/domdfcoding/default_values"
 repo_root = pathlib.Path(__file__).parent
